clear

*************************************************************************
* YOUR DIRECTORY HERE*
*************************************************************************

cd "C:\Users\Mantovani\Dropbox\Research\paper_predictions\data\source"



use dataset_call_randomprice, clear


*************************************************************************
*************************************************************************
* PRELIMINARIES and AUXILIARY*
*************************************************************************
*************************************************************************

**************************************************************************************************************************************************
************************* Estimates of the CRRA coefficient from individual demands**************************************************************
***** all estimates bounded to the maximum RA that can be estimated in the Investment game (32.48), for comparability. This is reported in footnote 26*****
***** estimates may take some time to run: jump to the following sections and use dataset_call_randomprice_thetadelta.dta to directly replicate the analalysis reported in the manuscript.*****************************
**************************************************************************************************************************************************

* Estimate theta considering 0<p<100, no delta. Used in robustness checks cited in footnote 27*

foreach i of numlist 1(1)258 {
	
	nl (q = (((100-p)^(1/{theta=1}))*(bayesbel^(1/{theta}))-(p^(1/{theta}))*((100-bayesbel)^(1/{theta})))*1000/(((100-p)*(p^(1/{theta}))*((100-bayesbel)^(1/{theta})))+(p*((100-p)^(1/{theta}))*(bayesbel^(1/{theta}))))) if id==`i' & bayesbel!=0 & bayesbel!=100, cluster(period)
	
	qui replace thetamkt1=_b[/theta] if id==`i'
	
	}
label variable thetamkt1 "Estimated theta, no delta, 0<p<100"
replace thetamkt1=32.48 if thetamkt1>32.48



* Estimate theta and delta considering 0<p<100. Not used in text but potentially usefull for further robustness checks*

foreach i of numlist 1(1)258 {
	list id if id ==`i' &p==50&period==1
		nl (q = (((100-p)^(1/{theta=1}))*(((1-{delta})*bayesbel+{delta}*50)^(1/{theta}))-(p^(1/{theta}))*((100-((1-{delta})*bayesbel+{delta}*50))^(1/{theta})))*1000/(((100-p)*(p^(1/{theta}))*((100-((1-{delta})*bayesbel+{delta}*50))^(1/{theta})))+(p*((100-p)^(1/{theta}))*(((1-{delta})*bayesbel+{delta}*50)^(1/{theta}))))) if id==`i' , cluster(period)
		

		qui replace thetamkt2=_b[/theta] if id==`i'
		qui replace delta2=_b[/delta] if id==`i'
		qui replace setheta2=_se[/theta] if id==`i'
		qui replace sedelta2=_se[/delta] if id==`i'
	
	}
label variable thetamkt2 "Estimated theta, with delta, 0<p<100"
label variable delta2 "0<p<100"

replace thetamkt2=32.48 if thetamkt2>32.48

save dataset_call_randomprice_thetadelta_0_100, replace

* Estimate theta considering 20<p<80, no delta. Main estimate with no delta used in text, unless explicitly stated*

keep if p>=20 &p<=80	
g thetamkt3=.
g setheta3=.
foreach i of numlist 1(1)258 {
	list id if id ==`i' &p==50&period==1
	nl (q = (((100-p)^(1/{theta=1}))*(bayesbel^(1/{theta}))-(p^(1/{theta}))*((100-bayesbel)^(1/{theta})))*1000/(((100-p)*(p^(1/{theta}))*((100-bayesbel)^(1/{theta})))+(p*((100-p)^(1/{theta}))*(bayesbel^(1/{theta}))))) if id==`i' & bayesbel!=0 & bayesbel!=100, cluster(period)
	
	qui replace thetamkt3=_b[/theta] if id==`i'
	qui replace setheta3=_se[/theta] if id==`i'
	
	}
label variable thetamkt3 "Estimated theta, no delta, 20<p<80"
replace thetamkt3=32.48 if thetamkt3>32.48

* Estimate theta and delta considering 20<p<80, with delta. Main estimate with delta used in text, unless explicitly stated*

g thetamkt4=.
g delta4=.
g setheta4=.
g sedelta4=.

	foreach i of numlist 1(1)64 {
		list id if id ==`i' &p==50&period==1
		nl (q = (((100-p)^(1/{theta=1}))*(((1-{delta})*bayesbel+{delta}*50)^(1/{theta}))-(p^(1/{theta}))*((100-((1-{delta})*bayesbel+{delta}*50))^(1/{theta})))*1000/(((100-p)*(p^(1/{theta}))*((100-((1-{delta})*bayesbel+{delta}*50))^(1/{theta})))+(p*((100-p)^(1/{theta}))*(((1-{delta})*bayesbel+{delta}*50)^(1/{theta}))))) if id==`i' , cluster(period)
		

		qui replace thetamkt4=_b[/theta] if id==`i'
		qui replace delta4=_b[/delta] if id==`i'
		qui replace setheta4=_se[/theta] if id==`i'
		qui replace sedelta4=_se[/delta] if id==`i'
		
		}
			
		nl (q = (((100-p)^(1/{theta=1}))*((50)^(1/{theta}))-(p^(1/{theta}))*((100-(50))^(1/{theta})))*1000/(((100-p)*(p^(1/{theta}))*((100-(50))^(1/{theta})))+(p*((100-p)^(1/{theta}))*((50)^(1/{theta}))))) if id==27 , cluster(period)

* ID 65 is basically inactive: unable to estimate for this subject.

		foreach i of numlist 66(1)258 {
		
		nl (q = (((100-p)^(1/{theta=1}))*(((1-{delta})*bayesbel+{delta}*50)^(1/{theta}))-(p^(1/{theta}))*((100-((1-{delta})*bayesbel+{delta}*50))^(1/{theta})))*1000/(((100-p)*(p^(1/{theta}))*((100-((1-{delta})*bayesbel+{delta}*50))^(1/{theta})))+(p*((100-p)^(1/{theta}))*(((1-{delta})*bayesbel+{delta}*50)^(1/{theta}))))) if id==`i' , cluster(period)
		
		list id if id ==`i' &p==50&period==1
		qui replace thetamkt4=_b[/theta] if id==`i'
		qui replace delta4=_b[/delta] if id==`i'
		qui replace setheta4=_se[/theta] if id==`i'
		qui replace sedelta4=_se[/delta] if id==`i'
		
		}
		

label variable thetamkt4 "Estimated theta, with delta, 20<p<80"
label variable delta4 "20<p<80"

replace thetamkt4=32.48 if thetamkt4>32.48 & thetamkt4!=.

*******************************************************************************************************************
*******GENEREATE EQUILIBRIUM PRICES FOR FIXED LEVEL THETA. Used in text: median level of thethamkt3 = 1.89 )**********
* the algorithm finds the price where the excess demand is as close to zero as possible*
***********************************************************************************************************************
preserve
keep if mkt==1
keep if p==50
g p_exp=.
g exc_q=.
g mediantheta=1.89
foreach i of numlist 10(1)980 {
	qui replace exc_q=10*((1-`i'/1000)^(1/mediantheta)*(bayesbel/100)^(1/mediantheta)- (`i'/1000)^(1/mediantheta)*(1-bayesbel/100)^(1/mediantheta))/((1-`i'/1000)*(`i'/1000)^(1/mediantheta)*(1-bayesbel/100)^(1/mediantheta)+(`i'/1000)*(1-`i'/1000)^(1/mediantheta)*(bayesbel/100)^(1/mediantheta))
	
	bysort mkt period: egen pippo`i'=sum(exc_q) if p==50
	qui replace pippo`i' = abs(pippo`i')
	qui replace p_exp=`i'/10 if pippo`i'<0.1
	qui replace p_exp=`i'/10 if pippo`i'<0.2 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<0.3 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<0.4 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<0.5 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<0.6 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<0.7 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<0.8 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<0.9 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<1 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<1.1 & p_exp==.
}
drop pippo*
bysort urn: egen price_medianthetamkt=max(p_exp) 
table urn,statistic(m price_median) 
collapse price_median, by(urn)
save price_median, replace
restore
merge m:1 urn using price_median.dta, update replace force
 

save dataset_call_randomprice_thetadelta, replace
		
*****************************************************************************************
*****************************************************************************************
**************************** SECTION 2: THEORY***************************************
****************************************************************************************
****************************************************************************************

*************************************************************************
**********     FIGURES and HYPOTHESES in SECTION 2 ********************
************************************************************************


use dataset_call_randomprice_thetadelta_0_100,clear

* FIGURE 1: graph with optimal demand for different levels of risk aversion

g belfix= 50
g thetafix= 1
g q_risk0= 1000/p if p<belfix
replace q_risk0= -1000/(100-p) if p>belfix 
replace q_risk0= 0 if p==belfix 
g q_risk1= (((100-p)^(1/thetafix))*((belfix)^(1/thetafix))-(p^(1/thetafix))*((100-(belfix))^(1/thetafix)))*1000/(((100-p)*(p^(1/thetafix))*((100-(belfix))^(1/thetafix)))+(p*((100-p)^(1/thetafix))*((belfix)^(1/thetafix))))
replace thetafix= 3
g q_risk3= (((100-p)^(1/thetafix))*((belfix)^(1/thetafix))-(p^(1/thetafix))*((100-(belfix))^(1/thetafix)))*1000/(((100-p)*(p^(1/thetafix))*((100-(belfix))^(1/thetafix)))+(p*((100-p)^(1/thetafix))*((belfix)^(1/thetafix))))

twoway (line p q_risk0 if q_risk0>= -50 & q_risk0<=50, sort lpattern(shortdash) lcolor(black)) (line p q_risk1 if q_risk1>= -50 & q_risk1<=50, sort lpattern(dash) lcolor(gs5) )(line p q_risk3 if q_risk3>= -50 & q_risk3<=50, sort lpattern(solid) lcolor(gs9)) , xline(0, lcolor(black)) yline(50,lpattern(dash) lcolor(black)) graphregion(color(white)) plotregion(margin(small))  xlabel(-50 "supply" 0 50 "demand") ylabel(0(100)100)  legend(order(1 "theta=0" 2 "theta=1" 3 "theta=3") cols(3)) ytitle(price) xtitle()


* FIGURE 3: graph with demand with informative prices
gen alpha_bel =.5
replace thetafix=1
g bel_informativep = alpha_bel*belfix +(1-alpha_bel)*p
g fictbel = 60
g q_fictbel3= (((100-p)^(1/thetafix))*((fictbel)^(1/thetafix))-(p^(1/thetafix))*((100-(fictbel))^(1/thetafix)))*1000/(((100-p)*(p^(1/thetafix))*((100-(fictbel))^(1/thetafix)))+(p*((100-p)^(1/thetafix))*((fictbel)^(1/thetafix))))
replace fictbel = 70
g q_fictbel4= (((100-p)^(1/thetafix))*((fictbel)^(1/thetafix))-(p^(1/thetafix))*((100-(fictbel))^(1/thetafix)))*1000/(((100-p)*(p^(1/thetafix))*((100-(fictbel))^(1/thetafix)))+(p*((100-p)^(1/thetafix))*((fictbel)^(1/thetafix))))
replace fictbel = 40
g q_fictbel2= (((100-p)^(1/thetafix))*((fictbel)^(1/thetafix))-(p^(1/thetafix))*((100-(fictbel))^(1/thetafix)))*1000/(((100-p)*(p^(1/thetafix))*((100-(fictbel))^(1/thetafix)))+(p*((100-p)^(1/thetafix))*((fictbel)^(1/thetafix))))
replace fictbel = 30
g q_fictbel1= (((100-p)^(1/thetafix))*((fictbel)^(1/thetafix))-(p^(1/thetafix))*((100-(fictbel))^(1/thetafix)))*1000/(((100-p)*(p^(1/thetafix))*((100-(fictbel))^(1/thetafix)))+(p*((100-p)^(1/thetafix))*((fictbel)^(1/thetafix))))
g q_risksuca= (((100-p)^(1/thetafix))*((bel_infor)^(1/thetafix))-(p^(1/thetafix))*((100-(bel_infor))^(1/thetafix)))*1000/(((100-p)*(p^(1/thetafix))*((100-(bel_infor))^(1/thetafix)))+(p*((100-p)^(1/thetafix))*((bel_infor)^(1/thetafix))))

twoway (line p q_risk1 if q_risk1>= -20 & q_risk1<=20, sort lpattern(dash) lcolor(black)) (line p q_fictbel2 if q_fictbel2>= -20 & q_fictbel2<=20, sort lpattern(dash) lcolor(gs7))(line p q_fictbel3 if q_fictbel3>= -20 & q_fictbel3<=20, sort lpattern(dash) lcolor(gs7))(line p q_risksuca if q_risksuca>= -20 & q_risksuca<=20, sort lpattern(solid) lcolor(black)) , xline(0, lcolor(black)) yline(50,lpattern(dash) lcolor(black)) graphregion(color(white)) plotregion(margin(small))  xlabel(-20 "supply" 0 20 "demand") ylabel(0 30 50 70 100)  legend(order(1 "non-strategic demand" 4 "partially informative prices" ) cols(2)) ytitle(price) xtitle()

*DERIVE HYPOTHESES 2 and 3 CRRA -- FIGURE 2*

use dataset_call_randomprice_thetadelta_0_100,clear

preserve
drop if mkt>1 | tag==0
g p_exp=.
g exc_q=.
foreach j of numlist 2(10)202 {
qui replace thetamkt1=`j'/100
qui replace p_exp=.
qui replace exc_q=.
foreach i of numlist 20(1)980 {
qui replace exc_q=10*((1-`i'/1000)^(1/thetamkt1)*(bayesbel/100)^(1/thetamkt1)- (`i'/1000)^(1/thetamkt1)*(1-bayesbel/100)^(1/thetamkt1))/((1-`i'/1000)*(`i'/1000)^(1/thetamkt1)*(1-bayesbel/100)^(1/thetamkt1)+(`i'/1000)*(1-`i'/1000)^(1/thetamkt1)*(bayesbel/100)^(1/thetamkt1))
bysort period: egen pippo`i'=sum(exc_q) 
qui replace pippo`i' = abs(pippo`i')
qui replace p_exp=`i'/10 if pippo`i'<0.01
qui replace p_exp=`i'/10 if pippo`i'<0.04 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.06 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.08 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.1 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.2 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.3 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.4 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.5 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.6 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.7 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.8 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.9 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<1 & p_exp==.
}
drop pippo*
bysort id period: egen equi_point`j'=max(p_exp) 
gen thetolone`j'= thetamkt1
}
egen tagurn= tag(urn)
drop if tag==0
drop if tagurn==0
reshape long equi_point, i(urn) j(thetolone)
keep urn thetolone equi_point bayes*
replace thetolone = thetolone/100

twoway (line equi_point thetolone if urn==4, lcolor(gs8) lpattern(dash))(line equi_point thetolone if urn==3, lcolor(black)), graphregion(color(white)) plotregion(margin(small))  xlabel(0(0.5)2) ylabel(50(10)80)  legend(order(1 "more information" 4 "less information" ) cols(2)) ytitle(equilibrium price (p*)) xtitle(risk aversion (theta, CRRA))

restore

*DERIVE HYPOTHESES 2 and 3 CARA -- FIGURE B.1*

preserve
g p_exp=.
g exc_q=.
g gamma=.
drop if mkt>1 | tag==0
foreach j of numlist 10(15)160 {
replace gamma=`j'/1000
replace p_exp=.
foreach i of numlist 20(1)980 {
qui replace exc_q=min((1/gamma)*(ln((bayesbel/100)/(`i'/1000))-ln((1-bayesbel/100)/(1-`i'/1000))), 10/(`i'/1000)) if (1/gamma)*(ln((bayesbel/100)/(`i'/1000))-ln((1-bayesbel/100)/(1-`i'/1000)))>=0
qui replace exc_q=max((1/gamma)*(ln((bayesbel/100)/(`i'/1000))-ln((1-bayesbel/100)/(1-`i'/1000))), -10/(1-(`i'/1000))) if (1/gamma)*(ln((bayesbel/100)/(`i'/1000))-ln((1-bayesbel/100)/(1-`i'/1000)))<0
qui replace exc_q=10/(`i'/1000) if bayesbel==100
qui replace exc_q=-10/(1-(`i'/1000)) if bayesbel==0
bysort period: egen pippo`i'=sum(exc_q) 
qui replace pippo`i' = abs(pippo`i')
qui replace p_exp=`i'/10 if pippo`i'<0.01
qui replace p_exp=`i'/10 if pippo`i'<0.04 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.06 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.08 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.1 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.2 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.3 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.4 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.5 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.6 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.7 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.8 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.9 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<1 & p_exp==.
}
drop pippo*
bysort id period: egen equi_point`j'=max(p_exp) 
gen thetolone`j'= gamma
}
egen tagurn= tag(urn)
drop if tag==0
drop if tagurn==0
reshape long equi_point, i(urn) j(thetolone)
keep urn thetolone equi_point bayes*
replace thetolone = thetolone/1000

twoway (line equi_point thetolone if urn==4, lcolor(gs8) lpattern(dash))(line equi_point thetolone if urn==3, lcolor(black)), graphregion(color(white)) plotregion(margin(small))  xlabel(0(0.05)0.17) ylabel(50(10)80)  legend(order(1 "more information" 4 "less information" ) cols(2)) ytitle(equilibrium price (p*)) xtitle(risk aversion (gamma, CARA))

restore


************************************************************************
*************************************************************************
**********SECTION 5: RESULTS********************
************************************************************************
*************************************************************************

***********************************
*Section 5.1 RANDOM versus CALL
**********************************
use dataset_call_randomprice_thetadelta_0_100,clear

* FIGURE 4: graph with aggregate demand in CA and RPM
preserve
statsby, clear by(treat p) : ci mean q
rename mean q
twoway connected p q if treat==0, sort color(black) msize(small)||  rcap lb ub p if treat==0, horizontal lcolor(black)|| connected p q if treat==1, sort color(gs6) msymbol(X) msize(small) || rcap lb ub p if treat==1 , horizontal lcolor(gs6)  graphregion(color(white)) plotregion(margin(small) color(white)) ytitle(price)  legend(order(1 "Call auction" 3 "Random price")) xline(0, lcolor(black) lwidth(thin)) xtitle() xlabel(-20 "supply" 0 20 "demand")
restore

*TEST RANDOM VS CALL****************

use dataset_call_randomprice_thetadelta,clear
preserve
collapse q, by(treat p)
g absq=abs(q)
ksmirnov absq,by(treat)
restore

*additional evidence cited on page 16 and footnote 20 and 27*

g slope= .
foreach i of numlist 1(1)258 {
		qui	reg q p bayesbel if id==`i' , cluster(period)
		qui replace slope=_b[p] if id==`i'
}

ranksum slope if p==50 &period==1, by(treat)
ranksum thetamkt3 if p==50 &period==1, by(treat)
ranksum thetamkt1 if p==50 &period==1, by(treat)



**************************************************
* Section 5.2 RISK AVERSION: INDIVIDUAL CHOICES *
**************************************************
use dataset_call_randomprice_thetadelta	,clear

*descriptives on investment game and FIGURE C.1 (footnote 22)
keep if treat==0
g absq=abs(q)
preserve 
keep if p==50 &period==1
codebook risk
codebook thetainv
restore

preserve
keep if p==50&period==1
cumul risk, gen(cumrisk)
collapse (max) cumrisk,by(risk)
twoway(line cumrisk risk, sort), graphregion(color(white)) plotregion(margin(small))  ytitle(cumulative) xtitle(Choice in the investment game)
restore

*Risk aversion and demands (RESULT 1)

preserve
keep if treat==0
collapse volume absq risk thetainv group, by(id)
cumul thetainv, gen(cumtheta)
g quartthetainv =0 
replace quartthetainv = 1 if cumtheta>.25
replace quartthetainv = 2 if cumtheta>.5
replace quartthetainv = 3 if cumtheta>.75
table quartthetainv, statistic(mean volume absq )
spearman absq thetainv
restore

*****************************************************
*Section 5.3: ELICITED RISK AVERSION AND MARKET PRICES*
************************************************
use dataset_call_randomprice_thetadelta	,clear
keep if treat==0

*Statistics cited in footnote 23 *
table session group if p == 50 & period==1, statistic(m risk)

* FIGURE 5: Boxplot
label define group 0 "high RA" 1 "low RA"
label values group group
graph box mktprice if p==50 , over(urn) over(group) graphregion(color(white)) plotregion(margin(small)) intensity(0) lines(lcolor(black)) marker(1,msize(small) mcolor(black))marker(2,msize(small) mcolor(black))marker(3,msize(small) mcolor(black))marker(4,msize(small) mcolor(black)) box(1, lcolor(black) fcolor(white))box(2,lcolor(black) fcolor(white))box(3,lcolor(black) fcolor(white))box(4,lcolor(black) fcolor(white))

*TABLE 3 (Rsults 2 and 3)*
preserve
keep if p==50 &treat==0
bysort mkt: egen priceA = mean(mktprice) if urn ==1
bysort mkt : egen mktpriceA = max(priceA) 
bysort mkt: egen priceB = mean(mktprice) if urn ==2
bysort mkt : egen mktpriceB = max(priceB) 
bysort mkt: egen priceC = mean(mktprice) if urn ==3
bysort mkt : egen mktpriceC = max(priceC) 
bysort mkt: egen priceD = mean(mktprice) if urn ==4
bysort mkt : egen mktpriceD = max(priceD) 
collapse  mktpriceA mktpriceB mktpriceC mktpriceD group, by(mkt)
*Top panel
signrank mktpriceA = mktpriceB 
signrank mktpriceB = mktpriceC 
signrank mktpriceC = mktpriceD 
bysort group: signrank mktpriceA = mktpriceB
bysort group: signrank mktpriceB = mktpriceC 
bysort group: signrank mktpriceC = mktpriceD 
*Median panel
ranksum mktpriceA , by(group)
ranksum mktpriceB , by(group)
ranksum mktpriceC , by(group)
ranksum mktpriceD , by(group)
*Bottom panel
g difab = mktpriceA - mktpriceB 
g difcd = mktpriceD - mktpriceC 
ranksum difab , by(group)
ranksum difcd , by(group)
restore

*statistics reported on p. 19: mean theta in investment game in low anfd high RA mkts and equilibrium prices for these values of RA*
table group if p==50&period==1, statistic(m thetainv)

preserve
keep if mkt==1
keep if p==50
g p_exp=.
g exc_q=.
g thetagroup0=0.23
foreach i of numlist 10(1)980 {
	qui replace exc_q=10*((1-`i'/1000)^(1/thetagroup0)*(bayesbel/100)^(1/thetagroup0)- (`i'/1000)^(1/thetagroup0)*(1-bayesbel/100)^(1/thetagroup0))/((1-`i'/1000)*(`i'/1000)^(1/thetagroup0)*(1-bayesbel/100)^(1/thetagroup0)+(`i'/1000)*(1-`i'/1000)^(1/thetagroup0)*(bayesbel/100)^(1/thetagroup0))
	
	bysort mkt period: egen pippo`i'=sum(exc_q) if p==50
	qui replace pippo`i' = abs(pippo`i')
	qui replace p_exp=`i'/10 if pippo`i'<0.1
	qui replace p_exp=`i'/10 if pippo`i'<0.2 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<0.3 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<0.4 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<0.5 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<0.6 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<0.7 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<0.8 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<0.9 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<1 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<1.1 & p_exp==.
}
drop pippo*
bysort urn: egen price_highRA=max(p_exp) 
replace p_exp=.
replace exc_q=.
g thetagroup1=1.19
foreach i of numlist 10(1)980 {
	qui replace exc_q=10*((1-`i'/1000)^(1/thetagroup1)*(bayesbel/100)^(1/thetagroup1)- (`i'/1000)^(1/thetagroup1)*(1-bayesbel/100)^(1/thetagroup1))/((1-`i'/1000)*(`i'/1000)^(1/thetagroup1)*(1-bayesbel/100)^(1/thetagroup1)+(`i'/1000)*(1-`i'/1000)^(1/thetagroup1)*(bayesbel/100)^(1/thetagroup1))
	
	bysort mkt period: egen pippo`i'=sum(exc_q) if p==50
	qui replace pippo`i' = abs(pippo`i')
	qui replace p_exp=`i'/10 if pippo`i'<0.1
	qui replace p_exp=`i'/10 if pippo`i'<0.2 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<0.3 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<0.4 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<0.5 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<0.6 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<0.7 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<0.8 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<0.9 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<1 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<1.1 & p_exp==.
}
drop pippo*
bysort urn: egen price_lowRA=max(p_exp) 
table urn, statistic(m price_lowRA  price_highRA) 
restore


* FIGURE 6: distance from bayesian belief vs average risk aversion of the market *
preserve
keep if p==50 &treat==0
gen finbayesspread = abs(bayesmean - mktprice)
label variable finbayesspread "abs deviation of closing price from average bayesian belief" 
bysort mkt: egen avgtheta= mean(thetainv)
twoway (lfitci finbayesspread avgtheta if avgtheta<=1.1, clcolor(black)  stdp level(95)) (scatter finbayesspread avgtheta if avgtheta<=1.1, msymbol(diamond) mcolor(gs5) msize(small)), graphregion(color(white)) plotregion(margin(small) color(white)) ytitle(Bias in prices (wrt avg Bayesian belief)) xtitle(avg CRRA coefficient in the market) legend(off) xtitle() xlabel(.2(.2)1.1) 
restore

* FIGURE C.3: distance from elicited belief vs average risk aversion of the market *
preserve
keep if p==50 &treat==0
bysort mkt period: egen elicitedmeanbel= mean(priorB)
gen pricebelspread = abs(elicitedmeanbel - mktprice)
label variable pricebelspread "abs deviation of closing price from average elicited belief" 
bysort mkt: egen avgtheta= mean(thetainv)
twoway (lfitci pricebelspread avgtheta if avgtheta<=1.1, clcolor(black)  stdp level(95)) (scatter pricebelspread avgtheta if avgtheta<=1.1, msymbol(diamond) mcolor(gs5) msize(small)), graphregion(color(white)) plotregion(margin(small) color(white)) ytitle(Bias in prices (wrt avg elicited belief)) xtitle(avg CRRA coefficient in the market) legend(off) xtitle() xlabel(.2(.2)1.1) 
restore


*risk-neutral and average market-clearing prices*
preserve
keep if mkt==1
keep if p==50
g p_exp=.
g exc_q=.
foreach i of numlist 10(1)980 {
	qui replace exc_q=10/(`i'/1000) if  bayesbel> (`i'/10)
	qui replace exc_q=-10/(1-(`i'/1000)) if  bayesbel<(`i'/10)
	qui replace exc_q=0 if  bayesbel==(`i'/10)
	
	bysort mkt period: egen pippo`i'=sum(exc_q)
	qui replace pippo`i' = abs(pippo`i')
	qui replace p_exp=`i'/10 if pippo`i'<0.1
	qui replace p_exp=`i'/10 if pippo`i'<0.2 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<0.3 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<0.4 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<0.5 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<0.6 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<0.7 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<0.8 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<0.9 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<1 & p_exp==.
	qui replace p_exp=`i'/10 if pippo`i'<1.1 & p_exp==.
}
drop pippo*
bysort urn: egen price_riskneutral=max(p_exp)
*When the urn is B or C the excess demand jumps from positive to negative around 50, therefore the algorithm cannot find an equilirbium price. The prices imputed here maximize the exchanges.
replace price_riskneutral=49.9 if price_riskneutral==. & urn==2
replace price_riskneutral=50.1 if price_riskneutral==. & urn==3
table urn, statistic(m price_riskneutral)
restore
g exposure= (1000-availablemoney)/1000
table urn if p==50, statistic(m mktprice bayesmean exposure)

********************************************************************************
********* Section 5.4 ESTIMATE OF INDIVIDUAL RISK AVERSION***********
*************************************************************************+
use dataset_call_randomprice_thetadelta	,clear
keep if treat==0

*median estimated theta from market (20<=p<=80) and investment game
codebook thetamkt3 if p==50 & period==1
codebook thetainv if p==50 & period==1

preserve
keep if p==50
collapse mktprice, by(period mkt)
tab mktprice 
restore

* FIGURE 7: Market-clearing prices are more incosnsistent with median CRRA as estimated from demands * 
preserve
keep if p==50
collapse mktprice urn bayesmean  price_median,by(mkt period)
g lb=.
g ub=.
ci means mktprice if urn==1
replace lb=r(lb) if urn==1
replace ub=r(ub) if urn==1
ci means mktprice if urn==2
replace lb=r(lb) if urn==2
replace ub=r(ub) if urn==2
ci means mktprice if urn==3
replace lb=r(lb) if urn==3
replace ub=r(ub) if urn==3
ci means mktprice if urn==4
replace lb=r(lb) if urn==4
replace ub=r(ub) if urn==4
g riskneutral_p = 49.9
replace riskneutral_p= 45.5 if urn==1
replace riskneutral_p= 50.1 if urn==3
replace riskneutral_p= 54.5 if urn==4
collapse riskneutral_p bayesmean price_median mktprice lb ub, by(urn)
twoway (connected riskneutral_p urn, sort msymbol(x) msize(large)  color(gs11)) (connected bayesmean urn, sort msymbol(Oh) msize(small) color(gs5)) (connected price_median urn, sort msymbol(O) msize(small) color(black) lpattern(dash)) (scatter mktprice urn, sort msymbol(Sh) msize(small) color(black)) (rcap lb ub urn, sort lcolor(black)), ylabel(20(10)80) graphregion(color(white)) plotregion(margin(small) color(white)) ytitle(Market-clearing price) xtitle(Urn) legend(order(1 "risk neutral" 2 "log-utility" 3 "median estimated CRRA" 4 "Observed")) xlabel(1 "A" 2 "B" 3 "C" 4 "D", valuelabel)
restore

* FIGURE 8: Observed and predicted aggregate net demand * 
g q_hat1= (((100-p)^(1/thetamkt3))*((bayesbel)^(1/thetamkt3))-(p^(1/thetamkt3))*((100-(bayesbel))^(1/thetamkt3)))*1000/(((100-p)*(p^(1/thetamkt3))*((100-(bayesbel))^(1/thetamkt3)))+(p*((100-p)^(1/thetamkt3))*((bayesbel)^(1/thetamkt3))))
g ubtheta3= thetamkt3 + 1.959964*setheta3
g lbtheta3= thetamkt3 - 1.959964*setheta3
g ubq_hat1= (((100-p)^(1/ubtheta3))*((bayesbel)^(1/ubtheta3))-(p^(1/ubtheta3))*((100-(bayesbel))^(1/ubtheta3)))*1000/(((100-p)*(p^(1/ubtheta3))*((100-(bayesbel))^(1/ubtheta3)))+(p*((100-p)^(1/ubtheta3))*((bayesbel)^(1/ubtheta3))))
g lbq_hat1= (((100-p)^(1/lbtheta3))*((bayesbel)^(1/lbtheta3))-(p^(1/lbtheta3))*((100-(bayesbel))^(1/lbtheta3)))*1000/(((100-p)*(p^(1/lbtheta3))*((100-(bayesbel))^(1/lbtheta3)))+(p*((100-p)^(1/lbtheta3))*((bayesbel)^(1/lbtheta3))))

preserve
collapse (sum) q q_hat1 ubq_hat1 lbq_hat1 (mean) urn, by(period mkt p)
collapse q q_hat1 ubq_hat1 lbq_hat1, by(urn p)
*trim values of confidence intervl to keep axis scale
replace ubq_hat1=160 if ubq_hat1>160
replace lbq_hat1=-160 if lbq_hat1<-160
twoway (rarea ubq lbq p if q_hat1>-150& q_hat1<150 , horizontal fintensity(70) color(gs14)  graphregion(color(white)) plotregion(margin(small) color(white))) (connected p q if q>-150& q<150 , sort msymbol(O) msize(small) color(black)  graphregion(color(white)) plotregion(margin(small) color(white))) (line p q_hat1 if q_hat1>-150& q_hat1<150 , sort lcolor(gs5)  graphregion(color(white)) plotregion(margin(small) color(white))) , by(urn, note("") graphregion(color(white)) plotregion(margin(small) color(white))) xline(0, lcolor(red)) xlabel(-150(150)150)  subtitle(, fcolor(none) lstyle(none)) xtitle()  graphregion(color(white)) plotregion(margin(small) color(white)) legend(order(2 "observed demand" 3 "estimated net demand (CRRA)")) xscale(range(-160 160))
restore

* FIGURE 9: Observed and predicted aggregate net demand if b_i == 66* 
preserve
collapse q q_hat1 ubq_hat1 lbq_hat1, by(infosignal p)
*trim values of confidence intervl to keep axis scale
replace ubq_hat1=16 if ubq_hat1>16
replace lbq_hat1=-16 if lbq_hat1<-16
replace lbq_hat1=16 if lbq_hat1>16
replace ubq_hat1=-16 if ubq_hat1<-16
twoway (rarea ubq lbq p, horizontal fintensity(70) color(gs14)) (connected p q, sort lcolor(black) mcolor(black) msize(medsmall)) (line p q_hat1, sort lcolor(gs5)) if infosignal==3 & q>-500& q<500 & q_hat1>-500& q_hat1<500, xline(0, lcolor(black) lpattern(dash)) yline(66.7, lcolor(red)) graphregion(color(white)) plotregion(margin(small) color(white)) ytitle(p)  legend(order(2 "avg net demand" 3 "CRRA")) xlabel(-5(5)16)
restore

*TABLE 4: Elicited beliefs about the state e= Blue and statistics reported around the discussion of Table 4*
preserve
g bel_error = abs(bayesbel-priorB)
sort id
tab thetainv
*median split on full sample (not by session as done to separate markets)
g thetainv_high=0
replace thetainv_high=1 if thetainvest>.33
tab thetainv_h
table infosignal if p==50, statistic(m bayesbel priorB)
table infosignal thetainv_h if p==50 , statistic(m bayesbel priorB )
collapse bel_error priorB thetainv_h thetainvest group, by(id)
spearman bel_error thetainvest
ranksum bel_error, by(thetainv_h)
ranksum priorB, by(thetainv_h)
restore

*descriptives on thetamkt4 and delta4, correlation between delta and payoffs
codebook thetamkt4 if p==50 & period==1
codebook delta4 if p==50 & period==1

preserve
keep if p==50 & period==1
signrank thetamkt4=thetamkt3
restore

egen avg_payoff = rowmean(mypayoff1 mypayoff2 mypayoff3 mypayoff4 mypayoff5 mypayoff6 mypayoff7 mypayoff8 mypayoff9 mypayoff10 mypayoff11 mypayoff12)
egen var_payoff = rowsd(mypayoff1 mypayoff2 mypayoff3 mypayoff4 mypayoff5 mypayoff6 mypayoff7 mypayoff8 mypayoff9 mypayoff10 mypayoff11 mypayoff12)
pwcorr avg_payoff var_payoff delta4 if period==1 & p==50 & treat==0, sig


* FIGURE 10: Observed and predicted aggregate net demand  -- WITH AND  WITHOUT DELTA* 
g q_hat2= (((100-p)^(1/thetamkt4))*(((1-delta4)*bayesbel+delta4*50)^(1/thetamkt4))-(p^(1/thetamkt4))*((100-((1-delta4)*bayesbel+delta4*50))^(1/thetamkt4)))*1000/(((100-p)*(p^(1/thetamkt4))*((100-((1-delta4)*bayesbel+delta4*50))^(1/thetamkt4)))+(p*((100-p)^(1/thetamkt4))*(((1-delta4)*bayesbel+delta4*50)^(1/thetamkt4))))
preserve
collapse (sum) q q_hat1 q_hat2 (mean) urn, by(period mkt p)
collapse q q_hat1 q_hat2, by(urn p)
twoway (connected p q if q>-150& q<150 , sort msymbol(O) msize(small) color(black)  graphregion(color(white)) plotregion(margin(small) color(white))) (line p q_hat1 if q_hat1>-150& q_hat1<150 , sort lcolor(gs10)  graphregion(color(white)) plotregion(margin(small) color(white))) (line p q_hat2 if q_hat2>-150& q_hat2<150 , sort lcolor(gs5)  graphregion(color(white)) plotregion(margin(small) color(white))) , by(urn, note("") graphregion(color(white)) plotregion(margin(small) color(white))) xline(0, lcolor(red)) xlabel(-150(150)150)  subtitle(, fcolor(none) lstyle(none)) xtitle()  graphregion(color(white)) plotregion(margin(small) color(white)) legend(cols(3) order(1 "observed demand" 2 "CRRA" 3 "CRRA+delta")) xscale(range(-160 160))
restore

* FIGURE 11: Observed and predicted aggregate net demand  -- WITH AND  WITHOUT DELTA* 
preserve
collapse (sum) q q_hat1 q_hat2 (mean) urn, by(period mkt p)
collapse q q_hat1 q_hat2, by(urn p)
keep if urn==1
g q_hat1area=q_hat1
replace q_hat1=-150 if q_hat1<-150
replace q_hat1area=0 if q_hat1<0 &q_hat2>0
twoway (rarea q_hat1 q_hat2 p if q_hat2>-150 & (q_hat2<0|q_hat1<0), horizontal sort fcolor(gs12) lcolor(gs12)  graphregion(color(white)) plotregion(margin(small) color(white))) (rarea q_hat1area q_hat2 p if q_hat2>0 , horizontal sort fcolor(gs8) lcolor(gs8)  graphregion(color(white)) plotregion(margin(small) color(white)))  (connected p q if q>-150& q<150 , sort msymbol(O) msize(small) color(gs6)  graphregion(color(white)) plotregion(margin(small) color(white))) (line p q_hat1 if q_hat1>-150& q_hat1<150 , sort lcolor(black) lpattern(dash)  graphregion(color(white)) plotregion(margin(small) color(white))) (line p q_hat2 if q_hat2>-150& q_hat2<150 , sort lcolor(black)  graphregion(color(white)) plotregion(margin(small) color(white))) , xline(0, lcolor(black) lpattern(dash) ) xlabel(-150(150)150)  subtitle(, fcolor(none) lstyle(none)) xtitle()  graphregion(color(white)) plotregion(margin(small) color(white)) legend(cols(3) order(3 "observed demand" 4 "CRRA" 5 "CRRA+delta")) xscale(range(-160 160))
restore

*Time trend on delta
g period2= period^2
g thetamkt_ag2=.
g delta_ag2=.
g setheta_ag2=.
g sedelta_ag2=.
g alphaperiod=.
g betaperiod=.
foreach i of numlist 1(1)20 {
		
nl (q = (((100-p)^(1/{theta=1}))*(((1-({delta}+{alpha}*period+{beta}*period2))*bayesbel+({delta}+{alpha}*period+{beta}*period2)*50)^(1/{theta}))-(p^(1/{theta}))*((100-((1-({delta}+{alpha}*period+{beta}*period2))*bayesbel+({delta}+{alpha}*period+{beta}*period2)*50))^(1/{theta})))*1000/(((100-p)*(p^(1/{theta}))*((100-((1-({delta}+{alpha}*period+{beta}*period2))*bayesbel+({delta}+{alpha}*period+{beta}*period2)*50))^(1/{theta})))+(p*((100-p)^(1/{theta}))*(((1-({delta}+{alpha}*period+{beta}*period2))*bayesbel+({delta}+{alpha}*period+{beta}*period2)*50)^(1/{theta}))))) if mkt==`i' , cluster(id)
	
		qui replace alphaperiod=_b[/alpha] if mkt==`i'
				qui replace betaperiod=_b[/beta] if mkt==`i'
		qui replace thetamkt_ag2=_b[/theta] if mkt==`i'
		qui replace delta_ag2=_b[/delta] if mkt==`i' 
		qui replace setheta_ag2=_se[/theta] if mkt==`i' 
		qui replace sedelta_ag2=_se[/delta] if mkt==`i' 
		}
g deltaperiod= delta_ag2+period*alphaperiod+period2*betaperiod
preserve
collapse deltaperiod, by(period)
table period, statistic(m deltaperiod)
twoway (line deltaperiod period, sort lcolor(gs2) mcolor(gs2)), yline(0.53, lcolor(red) lpattern(dash)) xlabel (1(1)12) ylabel(0.2(0.2)0.8) graphregion(color(white)) plotregion(margin(small) color(white)) ytitle(Predicted average delta)
restore			

*********************************************************************************************
*****Section 5.5 CONSISTENCY OF RISK AVERSION MEASURES *********************++ 
********************************************************************************************
use dataset_call_randomprice_thetadelta	,clear
keep if treat==0

spearman thetamkt4 thetainv if p==50 & period==1
spearman delta4 thetainv if p==50 & period==1
spearman delta4 thetamkt4 if p==50 & period==1


* TABLE 5
preserve 
keep if p==50 & period==1
g fin_illit=(finance=="nessuna conoscenza")
eststo clear
reg risk thetamkt4, robust cl(mkt)
eststo  
reg risk delta4, robust cl(mkt)
eststo 
reg risk thetamkt4 delta4, robust cl(mkt)
eststo 
reg risk thetamkt4 delta4 w_error fin_illit, robust cl(mkt)
eststo 
esttab  using thetamkt.tex, replace se compress fragment star(** 0.05 *** 0.01) scalars("r2_o R-squared") 
eststo clear
ranksum thetamkt4 if p==50 & period==1, by(group)
ranksum delta4 if p==50 & period==1, by(group)
restore


**********************************************************
****FIGURE C.2
**********************************************************

use dataset_call_randomprice_thetadelta_0_100,clear
keep if treat==0
keep if p==50


*drop if mkt>1 | tag==0
g p_exp=.
g exc_q=.
g predictedprice=.

*compute predicted prices for each market j in each period t given estimated theta from investment game and bayesian belief
foreach j of numlist 1(1)20 {
	foreach t of numlist 1(1)12 {
qui replace p_exp=.
qui replace exc_q=.
foreach i of numlist 20(1)980 {
qui replace exc_q=10*((1-`i'/1000)^(1/theta_inv)*(bayesbel/100)^(1/theta_inv)- (`i'/1000)^(1/theta_inv)*(1-bayesbel/100)^(1/theta_inv))/((1-`i'/1000)*(`i'/1000)^(1/theta_inv)*(1-bayesbel/100)^(1/theta_inv)+(`i'/1000)*(1-`i'/1000)^(1/theta_inv)*(bayesbel/100)^(1/theta_inv)) if mkt==`j' & period==`t'
qui replace exc_q=10/(`i'/1000) if mkt==`j' & period==`t' & (bayesbel==100|(theta_inv==0 & bayesbel*10>`i'))
qui replace exc_q=-10/(1-(`i'/1000)) if mkt==`j' & period==`t' & (bayesbel==0|(theta_inv==0 & bayesbel*10<`i'))
qui replace exc_q=0 if mkt==`j' & period==`t' & bayesbel*10==`i'
bysort mkt period: egen pippo`i'=sum(exc_q) 
qui replace pippo`i' = abs(pippo`i')
qui replace p_exp=`i'/10 if pippo`i'<0.01
qui replace p_exp=`i'/10 if pippo`i'<0.04 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.06 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.08 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.1 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.2 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.3 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.4 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.5 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.6 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.7 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.8 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<0.9 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<1 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<1.1 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<1.2 & p_exp==.
qui replace p_exp=`i'/10 if pippo`i'<1.3 & p_exp==.
}
drop pippo*
bysort mkt period: egen theprice=max(p_exp) 
qui replace predictedprice=theprice if mkt==`j'& period==`t'
drop theprice
}
}


preserve
collapse predictedprice group urn, by(mkt period)

g furn=urn-0.05*(-1)^group
twoway (scatter predictedprice furn if urn==1 &group==0, msymbol(circle) mcolor(gs9) msize(small))(scatter predictedprice furn if urn==1 &group==1, msymbol(circle) mcolor(gs2) msize(small)) (scatter predictedprice furn if urn==2 &group==0, msymbol(circle) mcolor(gs9) msize(small))(scatter predictedprice furn if urn==2 &group==1, msymbol(circle) mcolor(gs2) msize(small)) (scatter predictedprice furn if urn==3 &group==0, msymbol(circle) mcolor(gs9) msize(small))(scatter predictedprice furn if urn==3 &group==1, msymbol(circle) mcolor(gs2) msize(small)) (scatter predictedprice furn if urn==4 &group==0, msymbol(circle) mcolor(gs9) msize(small))(scatter predictedprice furn if urn==4 &group==1, msymbol(circle) mcolor(gs2) msize(small)), graphregion(color(white)) plotregion(margin(small)) xtitle("Urn") xlabel(1 "A" 2 "B" 3 "C" 4 "D") ylabel(30(10)70) ytitle("Predicted equilibrium price") legend(order(1 "High risk-aversion markets" 2 "Low risk-aversion markets"))	   
restore